<?xml version="1.0" ?><!DOCTYPE TS><TS language="sk" version="2.0">
<context>
    <name>AddProfileWindow</name>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="27"/>
        <source>Please enter a profile name.</source>
        <translation>Zadajte, prosím, názov profilu.</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="28"/>
        <source>A profile with this name already exists.</source>
        <translation>Takto pomenovaný profil už existuje.</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="24"/>
        <source>Save</source>
        <translation>Uložiť</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="25"/>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
</context>
<context>
    <name>AddRepoWindow</name>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="80"/>
        <source>Repository Path:</source>
        <translation>Umiestnenie repozitára:</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="83"/>
        <source>Choose Location of Borg Repository</source>
        <translation>Vyberte umiestnenie Borg repozitára</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="112"/>
        <source>Repository URL:</source>
        <translation>URL adresa repozitára:</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="138"/>
        <source>Unable to add your repository.</source>
        <translation>Nepodarilo sa pridať vami zadaný repozitár.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="165"/>
        <source>Please enter a valid repo URL or select a local path.</source>
        <translation>Vyberte platnú URL adresu repozitára alebo vyberte umiestnenie v tomto zariadení.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="169"/>
        <source>This repo has already been added.</source>
        <translation>Tento repozitár už bol pridaný.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="105"/>
        <source>Show my passwords</source>
        <translation>Zobraziť moje heslá</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="90"/>
        <source>Autofilled password from password manager.</source>
        <translation>Heslo predvyplnené Správcom hesiel</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="102"/>
        <source>Hide my passwords</source>
        <translation>Skryť moje heslá</translation>
    </message>
</context>
<context>
    <name>AddRepository</name>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="60"/>
        <source>Initialize New Backup Repository</source>
        <translation>Inicializovat nový repozitár pre zálohy</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="67"/>
        <source>Repository URL:</source>
        <translation>URL adresa repozitára:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="82"/>
        <source>csvis8xq@csvis8xq.repo.borgbase.com:repo</source>
        <translation>csvis8xq@csvis8xq.repo.borgbase.com:repo</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="89"/>
        <source>Choose a local path as repository.</source>
        <translation>Vybrať umiestnenie nachádzajúce sa na tomto zariadení ako repozitár.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="103"/>
        <source>...</source>
        <translation>…</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="201"/>
        <source>Encryption:</source>
        <translation>Šifrovanie:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="179"/>
        <source>SSH Key:</source>
        <translation>SSH kľúč:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="193"/>
        <source>Automatically choose SSH Key (default)</source>
        <translation>SSH kľúč vybrať automaticky (predvolené)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="247"/>
        <source>Add</source>
        <translation>Pridať</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="254"/>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="33"/>
        <source>General</source>
        <translation>Všeobecné</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="158"/>
        <source>Advanced</source>
        <translation>Pokročilé</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="218"/>
        <source>Extra Borg Arguments:</source>
        <translation>Ďalšie argumenty pre borg:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="116"/>
        <source>Borg passphrase:</source>
        <translation>Borg heslo:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="143"/>
        <source>Confirm passphrase:</source>
        <translation>Potvrdiť heslo:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="150"/>
        <source>TextLabel</source>
        <translation>TextovýPopisok</translation>
    </message>
</context>
<context>
    <name>ArchiveTab</name>
    <message>
        <location filename="../../views/archive_tab.py" line="144"/>
        <source>Archives for %s</source>
        <translation>Archívy pre %s</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="177"/>
        <source>Archives</source>
        <translation>Archívy</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="194"/>
        <source>Preview: %s</source>
        <translation>Náhľad: %s</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="198"/>
        <source>Error in archive name template.</source>
        <translation>Chyba v šablóne názvu archívu.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="242"/>
        <source>Pruning finished.</source>
        <translation>Vyčistenie dokončené.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="261"/>
        <source>Refreshed archives.</source>
        <translation>Archívy boli opätovne načítané.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="315"/>
        <source>Choose Mount Point</source>
        <translation>Vyberte bod pripojenia</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="321"/>
        <source>Mounted successfully.</source>
        <translation>Úspešne pripojené (mount).</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="348"/>
        <source>Mount point not active.</source>
        <translation>Bod pripojenia nie je aktívny.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="355"/>
        <source>Un-mounted successfully.</source>
        <translation>Odpojenie (unmount) bolo úspešné.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="393"/>
        <source>Select an archive to restore first.</source>
        <translation>Najprv vyberte archív, z ktorého budete obnovovať.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="413"/>
        <source>Choose Extraction Point</source>
        <translation>Vyberte bod, kam bude súbor/priečinok rozbalený</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="478"/>
        <source>Archive deleted.</source>
        <translation>Archív odstránený.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="463"/>
        <source>Confirm deletion</source>
        <translation>Potvrdiť odstránenie</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="563"/>
        <source>No archive selected</source>
        <translation>Nevybrali ste žiaden archív</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="463"/>
        <source>Are you sure you want to delete the archive?</source>
        <translation>Naozaj chcete tento archív odstrániť?</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="449"/>
        <source>Yes</source>
        <translation>Áno</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="450"/>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="98"/>
        <source>Action cancelled.</source>
        <translation>Operácia bola zrušená.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="361"/>
        <source>Unmounting failed. Make sure no programs are using {}</source>
        <translation>Odpájanie (unmount) skončilo s chybou. Ubezpečte sa, že žiaden program nepristupuje k {}</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="117"/>
        <source>Select an archive first.</source>
        <translation>Najprv vyberte archív.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="537"/>
        <source>Change name</source>
        <translation>Zmeniť názov</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="537"/>
        <source>New archive name:</source>
        <translation>Nový názov archívu:</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="547"/>
        <source>Archive name cannot be blank.</source>
        <translation>Názov archívu nesmie byť prázdny.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="552"/>
        <source>An archive with this name already exists.</source>
        <translation>Archív s takým názvom už existuje.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="567"/>
        <source>Archive renamed.</source>
        <translation>Archív bol premenovaný.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="278"/>
        <source>Refreshed archive.</source>
        <translation>Archív bol obnovený.</translation>
    </message>
</context>
<context>
    <name>BorgBreakJob</name>
    <message>
        <location filename="../../borg/break_lock.py" line="8"/>
        <source>Breaking repository lock...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/break_lock.py" line="12"/>
        <source>Repository lock broken. Please redo your last action.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgCheckJob</name>
    <message>
        <location filename="../../borg/check.py" line="8"/>
        <source>Starting consistency check...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/check.py" line="17"/>
        <source>Check completed.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/check.py" line="14"/>
        <source>Repo check failed. See logs for details.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgCreateJob</name>
    <message>
        <location filename="../../borg/create.py" line="36"/>
        <source>Backup finished with warnings. See logs for details.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/create.py" line="38"/>
        <source>Backup finished.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/create.py" line="45"/>
        <source>Backup started.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgDeleteJob</name>
    <message>
        <location filename="../../borg/delete.py" line="8"/>
        <source>Deleting archive...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/delete.py" line="13"/>
        <source>Archive deleted.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgDiffJob</name>
    <message>
        <location filename="../../borg/diff.py" line="9"/>
        <source>Requesting differences between archives...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/diff.py" line="13"/>
        <source>Obtained differences between archives.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgExtractJob</name>
    <message>
        <location filename="../../borg/extract.py" line="8"/>
        <source>Downloading files from archive...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/extract.py" line="13"/>
        <source>Restored files from archive.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgInfoArchiveJob</name>
    <message>
        <location filename="../../borg/info_archive.py" line="9"/>
        <source>Refreshing archive...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/info_archive.py" line="14"/>
        <source>Refreshing archive done.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgInfoRepoJob</name>
    <message>
        <location filename="../../borg/info_repo.py" line="9"/>
        <source>Validating existing repo...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgInitJob</name>
    <message>
        <location filename="../../borg/init.py" line="8"/>
        <source>Setting up new repo...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgJob</name>
    <message>
        <location filename="../../borg/borg_job.py" line="66"/>
        <source>Files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="67"/>
        <source>Original</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="68"/>
        <source>Deduplicated</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="69"/>
        <source>Compressed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="299"/>
        <source>Task started</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgListArchiveJob</name>
    <message>
        <location filename="../../borg/list_archive.py" line="8"/>
        <source>Getting archive content...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/list_archive.py" line="12"/>
        <source>Done getting archive content.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgListRepoJob</name>
    <message>
        <location filename="../../borg/list_repo.py" line="10"/>
        <source>Refreshing archives...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/list_repo.py" line="15"/>
        <source>Refreshing archives done.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgMountJob</name>
    <message>
        <location filename="../../borg/mount.py" line="9"/>
        <source>Mounting archive into folder...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgPruneJob</name>
    <message>
        <location filename="../../borg/prune.py" line="9"/>
        <source>Pruning old archives...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/prune.py" line="14"/>
        <source>Pruning done.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgUmountJob</name>
    <message>
        <location filename="../../borg/umount.py" line="10"/>
        <source>Unmounting archive...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialógové okno</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="25"/>
        <source>Archive:</source>
        <translation>Archív:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="38"/>
        <source>nyx2.local-2018-11-16T09:49:58 from November 16, 2018</source>
        <translation>nyx2.local-2018-11-16T09:49:58 z 16. novembra 2018</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="63"/>
        <source>Note: If you select a top-level folder and deselect its children, they will still be restored.</source>
        <translation>Pozn.: Ak vyberiete priečinok na vrchole stromu a potom zrušíte výber všetkých jeho potomkov, aj tak budú obnovené.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="88"/>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="95"/>
        <source>Extract</source>
        <translation>Rozbaliť</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="35"/>
        <source>Add Backup Profile</source>
        <translation>Pridať profil zálohovania</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Backup profiles allow for granular backups from different sources to different destinations. You could e.g. back up essential documents to a remote repository via Wifi, while doing a full backup onto a local storage device.&lt;/p&gt;&lt;p&gt;Repositories and SSH keys are shared between profiles. Source folders, active destination repo, allowed networks, pruning, validation and scheduling are per-profile.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Profily zálohovania vám umožnia detailne nastaviť zálohy z rôznych zdrojov na rôzne cieľové umiestnenia. Napríklad môžete zálohovať najdôležitejšie dokumenty do vzdialeného repozitára cez Wifi a zálohovať celý systém na lokálne úložisko.&lt;/p&gt;&lt;p&gt;Repozitáre a SSH kľúče sú zdieľané naprieč profilmi. Zdrojové priečinky, povolené siete, čistenie a overovanie archívov, plánovanie sú pre každý profil definované osobitne.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="84"/>
        <source>Profile Name</source>
        <translation>Názov profilu</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="43"/>
        <source>Generate SSH Key</source>
        <translation>Generovať SSH kľúč</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="55"/>
        <source>Key Format:</source>
        <translation>Formát kľúča:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="72"/>
        <source>Key Length:</source>
        <translation>Dĺžka kľúča:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="94"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;2048 or 4096 for RSA, 384 or 521 for ECDSA. Fixed for Ed25519. &lt;a href=&quot;https://stribika.github.io/2015/01/04/secure-secure-shell.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;More&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;2048 alebo 4096 pre RSA, 384 alebo 521 pre ECDSA. Pevné pre Ed25519. &lt;a href=&quot;https://stribika.github.io/2015/01/04/secure-secure-shell.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Viac na&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="107"/>
        <source>Output File:</source>
        <translation>Výstupný súbor:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="119"/>
        <source>Don&apos;t change this if you want SSH to automatically find the key.</source>
        <translation>Ak chcete, aby bol SSH kľúč nájdený automaticky, nemeňte toto nastavenie.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="128"/>
        <source>Close</source>
        <translation>Zavrieť</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="141"/>
        <source>Generate and copy to Clipboard</source>
        <translation>Generovať a kopírovať do schránky</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="25"/>
        <source>Select two archives</source>
        <translation>Vyberte dva archívy</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="60"/>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="65"/>
        <source>Size</source>
        <translation>Veľkosť</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="70"/>
        <source>Duration</source>
        <translation>Čas trvania</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="75"/>
        <source>Mount Point</source>
        <translation>Bod pripojenia</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="80"/>
        <source>Name</source>
        <translation>Názov</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="113"/>
        <source>Diff</source>
        <translation>Rozdiel</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="25"/>
        <source>Difference between</source>
        <translation>Rozdiely medzi</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="38"/>
        <source>nyx2.local-2018-11-16T09:49:58 </source>
        <translation>nyx2.local-2018-11-16T09:49:58 </translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="45"/>
        <source>and</source>
        <translation>a</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="58"/>
        <source>nyx2.local-2018-10-16T09:49:58 </source>
        <translation>nyx2.local-2018-10-16T09:49:58 </translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="101"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../assets/UI/exportwindow.ui" line="23"/>
        <source>If set, sharing this file with others will disclose your borg passphrase. Use with caution!</source>
        <translation>Ak túto voľbu nastavíte pri zdieľaní tohto súboru s ďalšími používateľmi im odhalíte vaše borg heslo. Buďte obozretní!</translation>
    </message>
    <message>
        <location filename="../../assets/UI/exportwindow.ui" line="26"/>
        <source>Include borg passphrase in export</source>
        <translation>Zahrnúť borg heslo do exportu</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="25"/>
        <source>Borg passphrase:</source>
        <translation>Borg heslo:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="53"/>
        <source>Overwrite existing profile</source>
        <translation>Prepísať existujúci profil</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="60"/>
        <source>Overwrite existing settings</source>
        <translation>Prepísať existujúce nastavenia</translation>
    </message>
</context>
<context>
    <name>EditProfileWindow</name>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="68"/>
        <source>Rename Profile</source>
        <translation>Premenovať profil</translation>
    </message>
</context>
<context>
    <name>ExistingRepoWindow</name>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="192"/>
        <source>Connect to existing Repository</source>
        <translation>Pripojiť sa k existujúcemu repozitáru</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="210"/>
        <source>Show my password</source>
        <translation>Zobraziť moje heslo</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="207"/>
        <source>Hide my password</source>
        <translation>Skryť moje heslo</translation>
    </message>
</context>
<context>
    <name>ExportWindow</name>
    <message>
        <location filename="../../views/export_window.py" line="29"/>
        <source>Export Profile</source>
        <translation>Exportovať profil</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="38"/>
        <source>The current profile_export has no password</source>
        <translation>Aktuálny export profilu neobsahuje heslo</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="43"/>
        <source>Save profile_export</source>
        <translation>Uložiť export profilu</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="55"/>
        <source>Error while exporting</source>
        <translation>Chyba počas exportu</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="71"/>
        <source>The file {} could not be created. Please choose another location.</source>
        <translation>Súbor {} sa nepodarilo vytvoriť. Prosím, vyberte iné umiestnenie.</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="78"/>
        <source>Profile export successful!</source>
        <translation>Export profilu bol úspešný!</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="78"/>
        <source>Profile export written to {}.</source>
        <translation>Export profilu bol zapísaný do {}.</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="14"/>
        <source>Form</source>
        <translation>Formulár</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="44"/>
        <source>Archives</source>
        <translation>Archívy</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="72"/>
        <source>Date</source>
        <translation>Dátum</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="79"/>
        <source>Size</source>
        <translation>Veľkosť</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="82"/>
        <source>Duration</source>
        <translation>Trvanie</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="87"/>
        <source>Mount Point</source>
        <translation>Bod pripojenia</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="92"/>
        <source>Name</source>
        <translation>Názov</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="125"/>
        <source>Check</source>
        <translation>Skontrolovať</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="145"/>
        <source>Prune</source>
        <translation>Vyčistiť</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="155"/>
        <source>Refresh</source>
        <translation>Znovu načítať</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="202"/>
        <source>Prune Options and Archive Naming</source>
        <translation>Nastavenie čistenia a pomenovania archívov</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="229"/>
        <source>Keep</source>
        <translation>Ponechať</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="256"/>
        <source>Use -1 for unlimited.</source>
        <translation>Pre neobmedzené použite -1 (mínus jedna).</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="249"/>
        <source> hourly, </source>
        <translation> hodinové, </translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="269"/>
        <source> daily, </source>
        <translation> denné, </translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="283"/>
        <source> weekly, </source>
        <translation> týždenné, </translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="297"/>
        <source> monthly and</source>
        <translation> mesačné a </translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="311"/>
        <source> annual archives</source>
        <translation> ročné archívy</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="338"/>
        <source>No matter what, keep all archives of the last:</source>
        <translation>Za každých okolností ponechávať všetky archívy za posledných:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="348"/>
        <source>24H, 1d, 52w, 12m, 1y</source>
        <translation>24h, 1d, 52t, 12m, 1r</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="388"/>
        <source>Archive Name:</source>
        <translation>Názov archívu:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="431"/>
        <source>Available variables: hostname, profile_id, profile_slug, now, utc_now, user</source>
        <translation>Dostupné premenne: hostname, profile_id, profile_slug, now, utc_now, user</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="398"/>
        <source>{hostname}-{profile_slug}-</source>
        <translation>{hostname}-{profile_slug}-</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="441"/>
        <source>Prune Prefix:</source>
        <translation>Predpona čistenia:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="71"/>
        <source>0.0</source>
        <translation>0.0</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="55"/>
        <source>Repository:</source>
        <translation>Repozitár:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="128"/>
        <source>Select Backup Destination</source>
        <translation>Vyberte umiestnenie zálohy</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="136"/>
        <source>Unlink Repository (This doesn&apos;t delete any data. You can always add a repo again later.)</source>
        <translation>Odpojiť repozitár (toto neodstráni žiadne údaje. Vždy môžete repozitár pridať naspäť.)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="164"/>
        <source>SSH Key:</source>
        <translation>SSH kľúč:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="185"/>
        <source>Copy public SSH key to clipboard.</source>
        <translation>Kopírovať verejnú časť SSH kľúča do schránky.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="222"/>
        <source>To securely access remote repositories. Keep default to use all your existing keys. Or create new key.</source>
        <translation>Na zabezpečenie prístupu do vzdialených repozitárov. Ak chcete využiť všetky vaše už vytvorené kľúče, ponechajte predvolené nastavenie. V opačnom prípade vytvorte nový kľúč.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="246"/>
        <source>Compression:</source>
        <translation>Kompresia:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="347"/>
        <source>Encryption:</source>
        <translation>Šifrovanie:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="387"/>
        <source>Original Size:</source>
        <translation>Pôvodná veľkosť:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="401"/>
        <source>Deduplicated Size:</source>
        <translation>Veľkosť po deduplikácii:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="408"/>
        <source>Compressed Size:</source>
        <translation>Veľkosť po skomprimovaní:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="45"/>
        <source>Schedule</source>
        <translation>Naplánovať</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="86"/>
        <source>Backup manually</source>
        <translation>Zálohovať ručne</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="143"/>
        <source>Backup every </source>
        <translation>Zálohovať každých(é) </translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="110"/>
        <source>Backup daily at</source>
        <translation>Zálohovať každý deň o</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="279"/>
        <source>Validate repository data every</source>
        <translation>Overiť správnosť dát v repozitári každých(é)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="299"/>
        <source>weeks</source>
        <translation> týždne</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="225"/>
        <source>Prune old Archives after each backup</source>
        <translation>Po každej zálohe vyčistiť staré archívy</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="191"/>
        <source>Next Backup:</source>
        <translation>Nasledujúca záloha:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="345"/>
        <source>Networks</source>
        <translation>Siete</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="357"/>
        <source>Allowed Networks:</source>
        <translation>Povolené siete:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="406"/>
        <source>Log</source>
        <translation>Záznam udalostí</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="431"/>
        <source>Time</source>
        <translation>Čas</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="436"/>
        <source>Category</source>
        <translation>Kategória</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="441"/>
        <source>Subcommand</source>
        <translation>Čiastkový príkaz</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="446"/>
        <source>Repository</source>
        <translation>Repozitár</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="451"/>
        <source>Returncode</source>
        <translation>Návratový kód</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="468"/>
        <source>Shell Commands</source>
        <translation>Príkazy shellu</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="477"/>
        <source>Run custom shell commands before and after each backup. The actual backup and post-backup command will only run, if the pre-backup command exits without error (return code 0).</source>
        <translation>Spúšťať príkazy shellu pred a po vykonaní každej zálohy. Záloha ako taká a príkaz spúšťaný po vykonaní zálohy bude spustený iba vtedy, ak príkaz spúšťaný pred zálohovaním skončí bez chýb (návratový kód 0).</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="496"/>
        <source>Pre-backup command to run BEFORE backups</source>
        <translation>Príkaz, ktorý sa vykoná PRED spustením zálohy</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="506"/>
        <source>Post-backup command to run AFTER backups</source>
        <translation>Príkaz, ktorý sa spustí PO skončení zálohovania</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="519"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Available env variables: &lt;span style=&quot; font-family:&apos;Courier&apos;;&quot;&gt;$repo_url, $profile_name, $profile_slug, $returncode&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Dostupné premenné prostredia: &lt;span style=&quot; font-family:&apos;Courier&apos;;&quot;&gt;$repo_url, $profile_name, $profile_slug, $returncode&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="20"/>
        <source>Source Folders and Files to Back Up:</source>
        <translation>Zdrojové priečinky a súbory, ktoré sa budú zálohovať:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="94"/>
        <source>Add Folder</source>
        <translation>Pridať priečinok</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="108"/>
        <source>Remove</source>
        <translation>Odobrať</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="164"/>
        <source>Exclude If Present (exclude folders with these files):</source>
        <translation>Ak sú prítomné, vynechať (preskočiť priečinky, ktoré obsahujú tieto súbory):</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="135"/>
        <source>Diff</source>
        <translation>Rozdiel</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="183"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;To mount archives, first install &amp;quot;FUSE for macOS&amp;quot; from &lt;a href=&quot;https://osxfuse.github.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;here&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Pre pripájanie archívov najprv nainštalujte „FUSE pre macOS“ &lt;a href=&quot;https://osxfuse.github.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;odtiaľto&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="208"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Pruning removes older archives. You can choose the number of hourly, daily, etc. archives to preserve. Usually you will keep more newer and fewer old archives. Read &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/prune.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#FF4500;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Čistenie odstráni staré archívy. Môžete vybrať počet archívov za jednotlivé hodiny, dni, atď, ktoré budú stále k dispozícii. Je zvykom ponechávať viac novších a menej starších archívov. Zistite &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/prune.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#FF4500;&quot;&gt;viac&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="64"/>
        <source>Vorta Version:</source>
        <translation>Verzia Vorta:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="81"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;| &lt;a href=&quot;https://github.com/borgbase/vorta/issues/new/choose&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Report&lt;/span&gt;&lt;/a&gt; a Bug |&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;| &lt;a href=&quot;https://github.com/borgbase/vorta/issues/new/choose&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Nahlásiť&lt;/span&gt;&lt;/a&gt; chybu |&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="91"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;file:///&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Log&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;file:///&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Záznam udalostí (log)&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="127"/>
        <source>Borg Version:</source>
        <translation>Verzia Borgu:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="134"/>
        <source>1.1.8</source>
        <translation>1.1.8</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="141"/>
        <source>/usr/bin/borg</source>
        <translation>/usr/bin/borg</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="96"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Remote or local backup repository. For simple and secure backup hosting, try &lt;a href=&quot;https://www.borgbase.com/?utm_source=vorta&amp;amp;utm_medium=app&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;BorgBase&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Repozitár pre zálohy na tomto alebo vzdialenom stroji. Pre jednoduché a zabezpečené hosťovanie zálohy vyskúšajte &lt;a href=&quot;https://www.borgbase.com/?utm_source=vorta&amp;amp;utm_medium=app&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;BorgBase&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="288"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Compression used for new data. Can be changed and doesn&apos;t affect deduplication. Read &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-compression&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Kompresia sa použije na nové dáta. Dá sa kedykoľvek zmeniť a nemá vplyv na deduplikáciu. Prečítajte &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-compression&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;viac&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="154"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Exclude Patterns (&lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-patterns&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;):&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Vzory pre vynechanie (&lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-patterns&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;viac&lt;/span&gt;&lt;/a&gt;):&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="180"/>
        <source>E.g. **/.cache</source>
        <translation>Napr. **/.cache</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="193"/>
        <source>E.g. .nobackup</source>
        <translation>Napr. nobackup</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="146"/>
        <source>Copy repo URL to clipboard</source>
        <translation>Kopírovať URL adresu repozitára do schránky</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="364"/>
        <source>Don&apos;t run backup over metered networks</source>
        <translation>Nespúšťať zálohovanie na sieťach s platenými dátami</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="101"/>
        <source>Add File(s)</source>
        <translation>Pridať súbor(y)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="115"/>
        <source>One folder or file per line</source>
        <translation>Každý priečinok alebo súbor na samostatnom riadku</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="118"/>
        <source>Paste Folders/Files</source>
        <translation>Vložiť priečinky/súbory</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="434"/>
        <source>{hostname}-{profile_slug}-{now:%Y-%m-%d-%H%M%S}</source>
        <translation>{hostname}-{profile_slug}-{now:%Y-%m-%d-%H%M%S}</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="69"/>
        <source>Path</source>
        <translation>Cesta k umiestneniu</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="74"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="84"/>
        <source>File Count</source>
        <translation>Počet súborov</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="125"/>
        <source>Recalculate sizes</source>
        <translation>Prepočítať veľkosť</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="102"/>
        <source>Selected Archive</source>
        <translation>Vybraný archív</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="542"/>
        <source>Add these arguments when creating a backup. See &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/create.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;the documentation&lt;/span&gt;&lt;/a&gt; for more information.</source>
        <translation>Pridať tieto prepínače pri vytváraní zálohy. Pozrite si &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/create.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;dokumentáciu&lt;/span&gt;&lt;/a&gt;, kde nájdete ďalšie informácie.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="558"/>
        <source>Arguments to add. E.g. --dry-run</source>
        <translation>Prepínače, ktoré budú pridané. Napr. --dry-run</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="198"/>
        <source>-</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="252"/>
        <source>Run missed backups right after startup or wakeup</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ImportWindow</name>
    <message>
        <location filename="../../views/import_window.py" line="25"/>
        <source>Import Profile</source>
        <translation>Importovať profil</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="33"/>
        <source>The passphrase has been loaded from the export file</source>
        <translation>Heslo bolo načítané zo súboru s exportom</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="40"/>
        <source>The passphrase has been loaded from your keyring</source>
        <translation>Heslo bolo načítané z kľúčenky</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="50"/>
        <source>A profile with the name {} does not exist. Nothing to overwrite.</source>
        <translation>Profil s názvom {} neexistuje. Nie je čo prepísať.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="61"/>
        <source>Error while importing</source>
        <translation>Chyba počas importu</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="77"/>
        <source>Schema upgrade failure, file a bug report with the link in the Misc tab with the following error: 
 {0} 
 {1}</source>
        <translation>Upgrade schémy skončil s chybou, otvorte hlásenie o chybe kliknutím na odkaz na karte Rôzne a skopírujte tento text:
{0}
{1}</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="80"/>
        <source>Newer profile_export export files cannot be used on older versions.</source>
        <translation>Novšie súbory s exportom profilu sa nedajú použiť v staršej verzii.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="82"/>
        <source>Cannot read profile_export export file due to permission error.</source>
        <translation>Nepodarilo sa prečítať súboru s exportom profilu kvôli nedostatočným oprávneniam.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="84"/>
        <source>Profile export file not found.</source>
        <translation>Súbor s exportom profilu nebol nájdený.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../views/main_window.py" line="255"/>
        <source>Task cancelled</source>
        <translation>Úloha zrušená</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="20"/>
        <source>MainWindow</source>
        <translation>Hlavné okno</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="51"/>
        <source>Current Profile:</source>
        <translation>Aktuálny profil:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="84"/>
        <source>Rename Profile</source>
        <translation>Premenovať profil</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="107"/>
        <source>Delete Profile</source>
        <translation>Odstrániť profil</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="148"/>
        <source>Repository</source>
        <translation>Repozitár</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="153"/>
        <source>Sources</source>
        <translation>Zdroje</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="158"/>
        <source>Schedule</source>
        <translation>Plán</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="163"/>
        <source>Archives</source>
        <translation>Archívy</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="168"/>
        <source>Misc</source>
        <translation>Rôzne</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="190"/>
        <source>Cancel</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="36"/>
        <source>Start Backup</source>
        <translation>Spustiť zálohu</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="239"/>
        <source>Latest</source>
        <translation>Najnovšie</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="244"/>
        <source>Reset App</source>
        <translation>Reštartovať aplikáciu</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="68"/>
        <source>Add Profile</source>
        <translation>Pridať profil</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="163"/>
        <source>Are you sure you want to delete profile &apos;{}&apos;?</source>
        <translation>Naozaj chcete odstrániť profil „{}“?</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="164"/>
        <source>Confirm deletion</source>
        <translation>Potvrdiť odstránenie</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="272"/>
        <source>Should Vorta continue to run in the background?</source>
        <translation>Má Vorta ďalej bežať na pozadí?</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="277"/>
        <source>Quit</source>
        <translation>Ukončiť</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="278"/>
        <source>Don&apos;t show this again</source>
        <translation>Túto správu už nezobrazovať</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="83"/>
        <source>Import from file...</source>
        <translation>Importovať zo súboru...</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="174"/>
        <source>Can&apos;t delete the last profile.</source>
        <translation>Nie je možné odstrániť posledný profil.</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="202"/>
        <source>Profile import successful!</source>
        <translation>Import profilu bol úspešný!</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="202"/>
        <source>Profile {} imported.</source>
        <translation>Profil {} bol importovaný.</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="211"/>
        <source>Load profile</source>
        <translation>Načítať profil</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="211"/>
        <source>JSON (*.json);;All files (*)</source>
        <translation>JSON (*.json);;Všetky súbory (*)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="97"/>
        <source>Export Profile</source>
        <translation>Exportovať profil</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="220"/>
        <source>Failed to import profile</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoTab</name>
    <message>
        <location filename="../../views/repo_tab.py" line="26"/>
        <source>+ Initialize New Repository</source>
        <translation>+ inicializovať nový repozitár</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="27"/>
        <source>+ Add Existing Repository</source>
        <translation>+ Pridať existujúci repozitár</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="48"/>
        <source>No Compression</source>
        <translation>Nekomprimovať</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="111"/>
        <source>Automatically choose SSH Key (default)</source>
        <translation>Vybrať SSH kľúč automaticky (predvolené)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="112"/>
        <source>Create New Key</source>
        <translation>Vytvoriť nový kľúč</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="149"/>
        <source>Public Key Copied to Clipboard</source>
        <translation>Verejná časť kľúča skopírovaná do schránky</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="150"/>
        <source>The selected public SSH key was copied to the clipboard. Use it to set up remote repo permissions.</source>
        <translation>Verejná časť vybraného SSH kľúča bola skopírovaná do schránky. Použite ju pre nastavenie práv k repozitáru na vzdialenej strane.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="155"/>
        <source>Couldn&apos;t find public key.</source>
        <translation>Verejnú časť kľúča sa nepodarilo nájsť.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="157"/>
        <source>Select a public key from the dropdown first.</source>
        <translation>Vyberte verejnú časť kľúca z rozbaľovacej ponuky.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="213"/>
        <source>Repository was Unlinked</source>
        <translation>Prepojenie repozitára bolo zrušené</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="214"/>
        <source>You can always connect it again later.</source>
        <translation>Vždy ho ale môžete pripojiť naspäť.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="38"/>
        <source>LZ4 (modern, default)</source>
        <translation>LZ4 (moderné, predvolené)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="39"/>
        <source>Zstandard Level 3 (modern)</source>
        <translation>Zstandard Level 3 (moderné)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="40"/>
        <source>Zstandard Level 8 (modern)</source>
        <translation>Zstandard Level 8 (moderné)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="46"/>
        <source>ZLIB Level 6 (auto, legacy)</source>
        <translation>ZLIB Level 6 (auto, zastarané)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="47"/>
        <source>LZMA Level 6 (auto, legacy)</source>
        <translation>LZMA Level 6 (auto, zastarané)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="228"/>
        <source>Select a repository from the dropdown first.</source>
        <translation>Z rozbaľovacej ponuky vyberte repozitár</translation>
    </message>
</context>
<context>
    <name>SSHAddWindow</name>
    <message>
        <location filename="../../views/ssh_dialog.py" line="35"/>
        <source>ED25519 (Recommended)</source>
        <translation>ED25519 (odporúčané)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="36"/>
        <source>RSA (Legacy)</source>
        <translation>RSA (zastarané)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="37"/>
        <source>ECDSA</source>
        <translation>ECDSA</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="46"/>
        <source>High (Recommended)</source>
        <translation>Vysoké (odporúčané)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="47"/>
        <source>Medium</source>
        <translation>Stredný</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="60"/>
        <source>Key file already exists. Not overwriting.</source>
        <translation>Súbor s kľúčom už existuje. Nebude prepísaný.</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="72"/>
        <source>New key was copied to clipboard and written to %s.</source>
        <translation>Nový kľúč bol skopírovaný do schránky a zapísaný do %s.</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="74"/>
        <source>Error during key generation.</source>
        <translation>Chyba pri generovaní kľúča.</translation>
    </message>
</context>
<context>
    <name>ScheduleTab</name>
    <message>
        <location filename="../../views/schedule_tab.py" line="43"/>
        <source>Minutes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../views/schedule_tab.py" line="44"/>
        <source>Hours</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../views/schedule_tab.py" line="45"/>
        <source>Days</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../views/schedule_tab.py" line="46"/>
        <source>Weeks</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SourceTab</name>
    <message>
        <location filename="../../views/source_tab.py" line="173"/>
        <source>Choose directory to back up</source>
        <translation>Vyberte priečinok, ktorý sa bude zálohovať</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="173"/>
        <source>Choose file(s) to back up</source>
        <translation>Vyberte súbory(y), které sa budú zálohovať</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="130"/>
        <source>Folder</source>
        <translation>Priečinok</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="134"/>
        <source>File</source>
        <translation>Súbor</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="102"/>
        <source>Calculating...</source>
        <translation>Počítam...</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="164"/>
        <source>You don&apos;t have read access to {dir}.</source>
        <translation>Nemáte práva na čítanie {dir}.</translation>
    </message>
</context>
<context>
    <name>TrayMenu</name>
    <message>
        <location filename="../../tray_menu.py" line="42"/>
        <source>Vorta for Borg Backup</source>
        <translation>Vorta pre Borg Backup</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="53"/>
        <source>Cancel Backup</source>
        <translation>Prerušiť zálohovanie</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="56"/>
        <source>Next Task: %s</source>
        <translation>Nasledujúca úloha: %s</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="65"/>
        <source>Backup Now</source>
        <translation>Zálohovať teraz</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="70"/>
        <source>Quit</source>
        <translation>Ukončiť</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="52"/>
        <source>Task in progress</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VortaApp</name>
    <message>
        <location filename="../../application.py" line="129"/>
        <source>Vorta Backup</source>
        <translation>Vorta Backup</translation>
    </message>
    <message>
        <location filename="../../application.py" line="191"/>
        <source>No Borg Binary Found</source>
        <translation>Nenajdený spustiteľný súbor nástroja Borg</translation>
    </message>
    <message>
        <location filename="../../application.py" line="192"/>
        <source>Vorta was unable to locate a usable Borg Backup binary.</source>
        <translation>Vorte sa nepodarilo nájsť použiteľný spustiteľný súbor nástroja Borg Backup.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="229"/>
        <source>Repository In Use</source>
        <translation>Používaný repozitár</translation>
    </message>
    <message>
        <location filename="../../application.py" line="231"/>
        <source>Abort</source>
        <translation>Zrušiť</translation>
    </message>
    <message>
        <location filename="../../application.py" line="232"/>
        <source>Continue</source>
        <translation>Pokračovať</translation>
    </message>
    <message>
        <location filename="../../application.py" line="234"/>
        <source>The repository at {repo_url} might be in use elsewhere.</source>
        <translation>Repozitár na {repo_url} môže byť použitý inde.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="235"/>
        <source>Only break the lock if you are certain no other Borg process on any machine is accessing the repository. Abort or break the lock?</source>
        <translation>Zámok rušte iba vtedy, ak ste si istý, že žiaden iný Borg proces na inom stroji nepristupuje k repozitáru. Odísť alebo zrušiť zámok?</translation>
    </message>
    <message>
        <location filename="../../application.py" line="243"/>
        <source>You do not have permission to access the repository at {repo_url}. Gain access and try again.</source>
        <translation>Nemáte oprávnenie pre prístup k repozitáru na {repo_url}. Získajte prístup a skúste to znovu.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="246"/>
        <source>No Repository Permissions</source>
        <translation>Chýbajúce práva k repozitáru</translation>
    </message>
    <message>
        <location filename="../../application.py" line="210"/>
        <source>Vorta needs Full Disk Access for complete Backups</source>
        <translation>Vorta vyžaduje plný prístup k disku pre úplné zálohy</translation>
    </message>
    <message>
        <location filename="../../application.py" line="211"/>
        <source>Without this, some files won&apos;t be accessible and you may end up with an incomplete backup. Please set &lt;b&gt;Full Disk Access&lt;/b&gt; permission for Vorta in &lt;a href=&apos;x-apple.systempreferences:com.apple.preference.security?Privacy&apos;&gt;System Preferences &gt; Security &amp; Privacy&lt;/a&gt;.</source>
        <translation>Bez neho nebudú niektoré súbory dostupné a záloha tak nemusí byť kompletná. Nastavte, prosím, &lt;b&gt;Plný prístup k disku&lt;/b&gt; pre Vorta v &lt;a href=&apos;x-apple.systempreferences:com.apple.preference.security?Privacy&apos;&gt;Nastavenia systému &gt; Bezpečnosť a súkromie&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="283"/>
        <source>Profile import successful!</source>
        <translation>Import profilu bol úspešný!</translation>
    </message>
    <message>
        <location filename="../../application.py" line="283"/>
        <source>Profile {} imported.</source>
        <translation>Profil {} bol importovaný.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="270"/>
        <source>Failed to import profile</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../application.py" line="270"/>
        <source>Failed to import a profile from {}:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../application.py" line="270"/>
        <source>Consider removing or repairing this file to get rid of this message.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../application.py" line="295"/>
        <source>Repo Check Failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../application.py" line="296"/>
        <source>Repository data check for repo %s failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../application.py" line="297"/>
        <source>Repair or recreate the repository soon to avoid missing data.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VortaScheduler</name>
    <message>
        <location filename="../../scheduler.py" line="143"/>
        <source>None scheduled</source>
        <translation>Nič nie je naplánované</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="190"/>
        <source>Vorta Backup</source>
        <translation>Vorta Backup</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="162"/>
        <source>Starting background backup for %s.</source>
        <translation>Spúšťanie zálohy na pozadí pre %s.</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="184"/>
        <source>Backup successful for %s.</source>
        <translation>Záloha %s bola úspešná.</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="190"/>
        <source>Error during backup creation.</source>
        <translation>Chyba pri vytváraní zálohy.</translation>
    </message>
</context>
<context>
    <name>app</name>
    <message>
        <location filename="../../__main__.py" line="22"/>
        <source>Fatal Error</source>
        <translation>Fatálna chyba</translation>
    </message>
    <message>
        <location filename="../../__main__.py" line="23"/>
        <source>Uncaught exception, please file a report with this text at
https://github.com/borgbase/vorta/issues/new
</source>
        <translation>Neošetrená výnimka, prosím, nahláste chybu (a skopírujte jej znenie)
na  https://github.com/borgbase/vorta/issues/new
</translation>
    </message>
</context>
<context>
    <name>messages</name>
    <message>
        <location filename="../../borg/version.py" line="20"/>
        <source>Borg binary was not found.</source>
        <translation>Spustiteľný súbor nástroja Borg nebol nájdený.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="140"/>
        <source>Add a backup repository first.</source>
        <translation>Najprv pridajte repozitár pre zálohy.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="82"/>
        <source>Add some folders to back up first.</source>
        <translation>Najprv pridajte do zálohy nejaké priečinky.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="98"/>
        <source>Current Wifi is not allowed.</source>
        <translation>Aktuálna sieť Wifi nie je povolená.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="115"/>
        <source>Repo folder not mounted or moved.</source>
        <translation>Priečinok s repozitárom nie je pripojený (mount) alebo bola presunutá.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="111"/>
        <source>Pre-backup command returned non-zero exit code.</source>
        <translation>Príkaz spúšťaný pred zálohou vrátil nenulový návratový kód (niečo sa nepodarilo).</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="165"/>
        <source>Starting backup...</source>
        <translation>Spúšťa sa záloha...</translation>
    </message>
    <message>
        <location filename="../../borg/umount.py" line="27"/>
        <source>No active Borg mounts found.</source>
        <translation>Neboli nájdené žiadne aktívne body pripojenia Borg (mount).</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="144"/>
        <source>Your Borg version is too old. &gt;=1.1.0 is required.</source>
        <translation>Verzia Borg, ktorú používate je príliš stará. Potrebujete verziu 1.1.0 alebo novšiu.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="119"/>
        <source>Your current Borg version does not support ZStd compression.</source>
        <translation>Verzia Borg, ktorú používate nepodporuje ZStd kompresiu.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="103"/>
        <source>Not running backup over metered connection.</source>
        <translation>Na pripojení s platenými dátami nie je povolené zálohovanie.</translation>
    </message>
    <message>
        <location filename="../../borg/info_repo.py" line="43"/>
        <source>Please unlock your password manager.</source>
        <translation>Prosím, odomknite vášho Správcu hesiel.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="171"/>
        <source>Your repo passphrase was stored in a password manager which is no longer available.
Try unlinking and re-adding your repo.</source>
        <translation>Heslo k vášmu repozitáru bolo uložené v Správcovi hesiel, ktorý už nie je dostupný.
Skúste tento repozitár odpojiť a opäť pridať.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="155"/>
        <source>Please unlock your system password manager or disable it under Misc</source>
        <translation>Prosím, odomknite prístup do Správcu hesiel alebo ho vypnite v Rôzne</translation>
    </message>
</context>
<context>
    <name>utils</name>
    <message>
        <location filename="../../utils.py" line="412"/>
        <source>Passwords must be identical and greater than 8 characters long.</source>
        <translation>Heslá musia byť identické a musia obsahovať aspoň 8 znakov.</translation>
    </message>
    <message>
        <location filename="../../utils.py" line="414"/>
        <source>Passwords must be identical.</source>
        <translation>Heslá musia byť identické.</translation>
    </message>
    <message>
        <location filename="../../utils.py" line="416"/>
        <source>Passwords must be greater than 8 characters long.</source>
        <translation>Heslá musia obsahovať aspoň 8 znakov.</translation>
    </message>
</context>
</TS>